"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var Clickable_1 = require("../Clickable");
var TextField_1 = require("../TextField");
var index_1 = require("./index");
describe('<EditableText />', function () {
    var component;
    var fakeEvent;
    beforeEach(function () {
        fakeEvent = {
            preventDefault: jest.fn(),
            stopPropagation: jest.fn(),
        };
    });
    describe('with promptText', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { promptText: "PROMPT TEXT" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { className: "TEST_CLASSNAME" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with all props except promptText', function () {
        var updateCallback;
        var beginCallback;
        var endCallback;
        beforeEach(function () {
            updateCallback = jest.fn();
            beginCallback = jest.fn();
            endCallback = jest.fn();
            component = enzyme_1.shallow(React.createElement(index_1.default, { text: "TEXT", placeHolder: "PLACEHOLDER", maxLength: 120, onUpdate: updateCallback, onBeginEditing: beginCallback, onEndEditing: endCallback }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('when clicked', function () {
            beforeEach(function () {
                component.find(Clickable_1.default).simulate('click', fakeEvent);
            });
            it('enters edit mode', function () {
                expect(component).toMatchSnapshot();
            });
            it('triggers the onBeginEditing callback', function () {
                expect(beginCallback).toHaveBeenCalledTimes(1);
            });
            // Getting coverage on componentDidUpdate, necessary because of https://github.com/airbnb/enzyme/issues/1452
            describe('when triggered to enter edit mode again', function () {
                beforeEach(function () {
                    component.instance().componentDidUpdate({}, { isEditing: true });
                });
                it('remains in edit mode', function () {
                    expect(component).toMatchSnapshot();
                });
            });
            // Getting coverage on setTextFieldFocus, necessary because of https://github.com/airbnb/enzyme/issues/1452
            describe('when triggered to enter edit mode without private textFieldRef', function () {
                beforeEach(function () {
                    component.instance().componentDidUpdate({}, { isEditing: false });
                });
                it('remains in edit mode', function () {
                    expect(component).toMatchSnapshot();
                });
            });
            describe('and text is changed', function () {
                beforeEach(function () {
                    var onChange = component.find(TextField_1.default).prop('onChange');
                    onChange('new text');
                });
                describe('and ENTER is pressed', function () {
                    beforeEach(function () {
                        var onKeyDown = component.find(TextField_1.default).prop('onKeyDown');
                        onKeyDown({ which: 13, preventDefault: jest.fn() });
                        component.update();
                    });
                    it('exits edit mode', function () {
                        expect(component).toMatchSnapshot();
                    });
                    it('triggers the update callback with the correct value', function () {
                        expect(updateCallback).toHaveBeenCalledWith('new text');
                    });
                    it('triggers the onEndEditing callback', function () {
                        expect(endCallback).toHaveBeenCalledTimes(1);
                    });
                });
                describe('and ESC is pressed', function () {
                    beforeEach(function () {
                        var onKeyDown = component.find(TextField_1.default).prop('onKeyDown');
                        onKeyDown({ which: 27, preventDefault: jest.fn() });
                        component.update();
                    });
                    it('exits edit mode', function () {
                        expect(component).toMatchSnapshot();
                    });
                    it('does not trigger the update callback', function () {
                        expect(updateCallback).not.toHaveBeenCalled();
                    });
                    it('triggers the onEndEditing callback', function () {
                        expect(endCallback).toHaveBeenCalledTimes(1);
                    });
                });
                describe('and an unimportant key is pressed', function () {
                    beforeEach(function () {
                        var onKeyDown = component.find(TextField_1.default).prop('onKeyDown');
                        onKeyDown({ which: 65, preventDefault: jest.fn() });
                        component.update();
                    });
                    it('remains in edit mode', function () {
                        expect(component).toMatchSnapshot();
                    });
                    it('does not trigger the update callback', function () {
                        expect(updateCallback).not.toHaveBeenCalled();
                    });
                    it('does not trigger the onEndEditing callback', function () {
                        expect(endCallback).not.toHaveBeenCalled();
                    });
                });
            });
        });
    });
    describe('without props', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, null));
        });
        describe('when clicked', function () {
            beforeEach(function () {
                component.find(Clickable_1.default).simulate('click', fakeEvent);
            });
            describe('and text is changed', function () {
                beforeEach(function () {
                    var onChange = component.find(TextField_1.default).prop('onChange');
                    onChange('new text');
                });
                describe('and ENTER is pressed', function () {
                    beforeEach(function () {
                        var onKeyDown = component.find(TextField_1.default).prop('onKeyDown');
                        onKeyDown({ which: 13, preventDefault: jest.fn() });
                        component.update();
                    });
                    it('exits edit mode', function () {
                        expect(component).toMatchSnapshot();
                    });
                });
                describe('and ESC is pressed', function () {
                    beforeEach(function () {
                        var onKeyDown = component.find(TextField_1.default).prop('onKeyDown');
                        onKeyDown({ which: 27, preventDefault: jest.fn() });
                        component.update();
                    });
                    it('exits edit mode', function () {
                        expect(component).toMatchSnapshot();
                    });
                });
            });
        });
        describe('when focusableRefs are provided', function () {
            var clickableFocusable;
            var textFieldFocusable;
            beforeEach(function () {
                // Populate the mock focus listeners. We need to force the control into
                // edit mode, and then close it back up again, just so that we can inject
                // both of these ahead of testing.
                clickableFocusable = { focus: jest.fn() };
                var setClickableFocusable = component.find(Clickable_1.default).prop('focusableRef');
                setClickableFocusable(clickableFocusable);
                // Force the component open...
                component.find(Clickable_1.default).simulate('click', fakeEvent);
                // Now we can hook up the focusable ref for the TextField...
                textFieldFocusable = { focus: jest.fn() };
                var setTextFieldFocusable = component.find(TextField_1.default).prop('focusableRef');
                setTextFieldFocusable(textFieldFocusable);
                // Now close the component to get back to initial state for the actual testing...
                var onKeyDown = component.find(TextField_1.default).prop('onKeyDown');
                onKeyDown({ which: 27, preventDefault: jest.fn() });
                component.update();
            });
            describe('when the component enters edit mode', function () {
                beforeEach(function () {
                    component.find(Clickable_1.default).simulate('click', fakeEvent);
                    // Force componentDidUpdate() since enzyme isn't allowing internal setState to trigger componentDidUpdate
                    // https://github.com/airbnb/enzyme/issues/1452
                    component.instance().componentDidUpdate({}, { isEditing: false });
                });
                it('focuses its text input', function () {
                    expect(textFieldFocusable.focus).toHaveBeenCalledTimes(1);
                });
                describe('when the component leaves edit mode', function () {
                    beforeEach(function () {
                        var onKeyDown = component.find(TextField_1.default).prop('onKeyDown');
                        onKeyDown({ which: 27, preventDefault: jest.fn() });
                        component.update();
                        // Force componentDidUpdate() since enzyme isn't allowing internal setState to trigger componentDidUpdate
                        // https://github.com/airbnb/enzyme/issues/1452
                        component.instance().componentDidUpdate({}, { isEditing: true });
                    });
                    it('restores focus to the clickable', function () {
                        expect(clickableFocusable.focus).toHaveBeenCalledTimes(1);
                    });
                });
            });
        });
    });
});
//# sourceMappingURL=EditableText.test.js.map