"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var enzyme_1 = require("enzyme");
var Callout_1 = require("../Callout");
var _1 = require(".");
jest.useFakeTimers();
describe('<Hovercard />', function () {
    var component;
    var fullComponent;
    describe('with default options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content") },
                React.createElement("span", null, "Trigger")));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with additional className', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content"), className: "TEST_CLASSNAME" },
                React.createElement("span", null, "Trigger")));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('with screenreaderTitle', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content"), screenreaderTitle: "HIDDEN TITLE", triggerType: _1.TriggerType.CLICK },
                React.createElement("span", null, "Trigger")));
            component.find('.y-hovercard--trigger').simulate('click');
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
    });
    describe('hovercard gets displayed', function () {
        it('via click', function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content"), triggerType: _1.TriggerType.CLICK },
                React.createElement("span", null, "Trigger")));
            component.find('.y-hovercard--trigger').simulate('click');
            expect(component.find('.y-hovercard--modal-container').length).toBe(1);
        });
        it('via hover after delay', function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content") },
                React.createElement("span", null, "Trigger")));
            component.find('.y-hovercard--trigger').simulate('mouseEnter');
            jest.advanceTimersByTime(750);
            expect(component.update().find('.y-hovercard--modal-container').length).toBe(1);
        });
    });
    describe('hovercard properly does not display', function () {
        it('when clicking a hover trigger', function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content") },
                React.createElement("span", null, "Trigger")));
            component.find('.y-hovercard--trigger').simulate('click');
            jest.advanceTimersByTime(750);
            expect(component.find('.y-hovercard--modal-container').length).toBe(0);
        });
        it('when hovering over a click trigger', function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content"), triggerType: _1.TriggerType.CLICK },
                React.createElement("span", null, "Trigger")));
            component.find('.y-hovercard--trigger').simulate('mouseEnter');
            jest.advanceTimersByTime(750);
            expect(component.find('.y-hovercard--modal-container').length).toBe(0);
        });
    });
    describe('mousing over the trigger', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content") },
                React.createElement("span", null, "Trigger")));
            component.find('.y-hovercard--trigger').simulate('mouseEnter');
            jest.advanceTimersByTime(250);
        });
        it('does not show the hovercard before the show timeout completes', function () {
            expect(component.find('.y-hovercard--modal-container').length).toBe(0);
        });
        describe('then mousing back out before the hovercard is displayed', function () {
            beforeEach(function () {
                component.find('.y-hovercard--trigger').simulate('mouseLeave');
            });
            it('cancels the hovercard from being displayed', function () {
                jest.runAllTimers();
                expect(component.find('.y-hovercard--modal-container').length).toBe(0);
            });
        });
    });
    describe('when visible', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content") },
                React.createElement("span", null, "Trigger")));
            component.find('.y-hovercard--trigger').simulate('mouseEnter');
            jest.advanceTimersByTime(750);
            component.update();
        });
        it('is visible', function () {
            expect(component.find('.y-hovercard--modal-container').length).toBe(1);
        });
        describe('and then unmounted', function () {
            beforeEach(function () {
                component.unmount();
            });
            it('should clearTimeout on the window', function () {
                expect(window.clearTimeout).toHaveBeenCalled();
            });
        });
        describe('and the mouse hovers out of the trigger', function () {
            beforeEach(function () {
                component.find('.y-hovercard--trigger').simulate('mouseLeave');
            });
            it('the Hovercard closes after a delay', function () {
                jest.advanceTimersByTime(500);
                expect(component.update().find(Callout_1.default).length).toBe(0);
            });
            describe('mousing back in', function () {
                beforeEach(function () {
                    jest.advanceTimersByTime(250);
                    component.find('.y-hovercard--trigger').simulate('mouseEnter');
                });
                it('prevents the hovercard from closing', function () {
                    jest.advanceTimersByTime(500);
                    expect(component.update().find(Callout_1.default).length).toBe(1);
                });
                describe('and mousing back out', function () {
                    beforeEach(function () {
                        component.find('.y-hovercard--trigger').simulate('mouseLeave');
                    });
                    it('allows the Hovercard to close', function () {
                        jest.advanceTimersByTime(500);
                        expect(component.update().find(Callout_1.default).length).toBe(0);
                    });
                });
            });
        });
        describe('and the mouse hovers out of the modal body', function () {
            beforeEach(function () {
                component.find('.y-hovercard--modal-container').simulate('mouseLeave');
            });
            describe('mousing back in', function () {
                beforeEach(function () {
                    jest.advanceTimersByTime(250);
                    component
                        .update()
                        .find('.y-hovercard--modal-container')
                        .simulate('mouseEnter');
                });
                it('prevents the hovercard from closing', function () {
                    jest.advanceTimersByTime(500);
                    expect(component.update().find(Callout_1.default).length).toBe(1);
                });
                describe('and mousing back out', function () {
                    beforeEach(function () {
                        component.find('.y-hovercard--modal-container').simulate('mouseLeave');
                    });
                    it('allows the Hovercard to close', function () {
                        jest.advanceTimersByTime(500);
                        expect(component.update().find(Callout_1.default).length).toBe(0);
                    });
                });
            });
        });
        describe('and the ESC key is pressed', function () {
            beforeEach(function () {
                var event = new KeyboardEvent('keydown', { keyCode: 27 /* escape */ });
                document.dispatchEvent(event);
            });
            it('the Hovercard closes immediately', function () {
                expect(component.update().find(Callout_1.default).length).toBe(0);
            });
        });
        describe('and a non-ESC key is pressed', function () {
            beforeEach(function () {
                var event = new KeyboardEvent('keydown', { keyCode: 13 /* enter */ });
                document.dispatchEvent(event);
            });
            it('the Hovercard remains open', function () {
                expect(component.find(Callout_1.default).length).toBe(1);
            });
        });
    });
    describe('does not start visible by default', function () {
        beforeEach(function () {
            // Need to fully render to fire off componentDidMount
            fullComponent = enzyme_1.mount(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content") },
                React.createElement("span", null, "Trigger")));
        });
        it('renders the Hovercard', function () {
            expect(fullComponent.find(Callout_1.default).length).toBe(0);
        });
    });
    describe('when asked to start visible', function () {
        beforeEach(function () {
            // Need to fully render to fire off componentDidMount
            fullComponent = enzyme_1.mount(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content"), startVisible: true },
                React.createElement("span", null, "Trigger")));
        });
        it('renders the Hovercard', function () {
            expect(fullComponent.find(Callout_1.default).length).toBe(1);
        });
        describe('when a hover out triggers its close timeout', function () {
            beforeEach(function () {
                fullComponent.find('.y-hovercard--trigger').simulate('mouseLeave');
            });
            describe('and the component is unmounted before the timeout completes', function () {
                beforeEach(function () {
                    jest.advanceTimersByTime(250);
                    fullComponent.unmount();
                });
                it('the timeout has been cleared without throwing an error', function () {
                    jest.advanceTimersByTime(500);
                    expect(fullComponent.find('.y-hovercard--trigger').length).toEqual(0);
                });
            });
        });
    });
    describe('callbacks', function () {
        var onHover;
        var onShow;
        var onHide;
        beforeEach(function () {
            onHover = jest.fn();
            onShow = jest.fn();
            onHide = jest.fn();
            component = enzyme_1.shallow(React.createElement(_1.Hovercard, { content: React.createElement("div", null, "Hovercard content"), onTriggerHover: onHover, onContentDisplay: onShow, onContentDismiss: onHide },
                React.createElement("span", null, "Trigger")));
        });
        describe('when trigger content is hovered', function () {
            beforeEach(function () {
                component.find('.y-hovercard--trigger').simulate('mouseEnter');
            });
            it('onTriggerHover() is called', function () {
                expect(onHover.mock.calls.length).toBe(1);
            });
            describe('when Hovercard content pops up', function () {
                beforeEach(function () {
                    jest.runAllTimers();
                });
                it('onContentDisplay is called when shown', function () {
                    expect(onShow.mock.calls.length).toBe(1);
                });
                describe('when Hovercard content is removed', function () {
                    beforeEach(function () {
                        component.find('.y-hovercard--trigger').simulate('mouseLeave');
                        jest.runAllTimers();
                    });
                    it('onContentDismiss is called', function () {
                        expect(onHide.mock.calls.length).toBe(1);
                    });
                });
            });
        });
    });
});
//# sourceMappingURL=Hovercard.test.js.map