"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*! Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license. */
var React = require("react");
var react_intersection_observer_1 = require("react-intersection-observer");
var enzyme_1 = require("enzyme");
var index_1 = require("./index");
describe('<VisibilityObserver />', function () {
    var component;
    var renderInView = function () { return React.createElement("span", null, "IN VIEW"); };
    var renderOutOfView = function () { return React.createElement("span", null, "OUT OF VIEW"); };
    var onEnterCallback;
    var onLeaveCallback;
    var renderProp;
    var callbackProp;
    beforeEach(function () {
        onEnterCallback = jest.fn();
        onLeaveCallback = jest.fn();
    });
    describe('with minimal options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, null));
            renderProp = component.find(react_intersection_observer_1.default).prop('render');
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        it('renders empty content via its in-view render prop', function () {
            expect(renderProp(true)).toMatchSnapshot();
        });
    });
    describe('with render, callback, rootMargin and tag options', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { renderInView: renderInView, renderOutOfView: renderOutOfView, onEnterView: onEnterCallback, onLeaveView: onLeaveCallback, rootMargin: "100px", tag: "span" }));
        });
        it('matches its snapshot', function () {
            expect(component).toMatchSnapshot();
        });
        describe('Observer rendering', function () {
            beforeEach(function () {
                renderProp = component.find(react_intersection_observer_1.default).prop('render');
            });
            it('in view render matches its snapshot', function () {
                expect(renderProp(true)).toMatchSnapshot();
            });
            it('out of view render matches its snapshot', function () {
                expect(renderProp(false)).toMatchSnapshot();
            });
        });
        describe('Observer callbacks', function () {
            beforeEach(function () {
                callbackProp = component.find(react_intersection_observer_1.default).prop('onChange');
                renderProp = component.find(react_intersection_observer_1.default).prop('render');
            });
            describe('when in view', function () {
                beforeEach(function () {
                    callbackProp(true);
                });
                it('in view callback is properly called', function () {
                    expect(onEnterCallback).toHaveBeenCalled();
                });
                describe('and scrolled back out of view', function () {
                    beforeEach(function () {
                        callbackProp(false);
                    });
                    it('the in-view render prop remains rendered', function () {
                        expect(renderProp(true)).toMatchSnapshot();
                    });
                });
            });
            describe('when out of view', function () {
                beforeEach(function () {
                    callbackProp(false);
                });
                it('out of view callback is properly called', function () {
                    expect(onLeaveCallback).toHaveBeenCalled();
                });
            });
        });
    });
    describe('without callbacks', function () {
        beforeEach(function () {
            component = enzyme_1.shallow(React.createElement(index_1.default, { renderInView: renderInView, renderOutOfView: renderOutOfView }));
            callbackProp = component.find(react_intersection_observer_1.default).prop('onChange');
            renderProp = component.find(react_intersection_observer_1.default).prop('render');
        });
        describe('when out of view', function () {
            it('renders without blowing up', function () {
                expect(renderProp(false)).toMatchSnapshot();
            });
            describe('and scrolled into view', function () {
                beforeEach(function () {
                    callbackProp(true);
                });
                it('renders without blowing up', function () {
                    expect(renderProp(true)).toMatchSnapshot();
                });
                describe('and scrolled out of view', function () {
                    beforeEach(function () {
                        callbackProp(false);
                    });
                    it('persists its in-view content without blowing up', function () {
                        expect(renderProp(false)).toMatchSnapshot();
                    });
                });
            });
        });
    });
});
//# sourceMappingURL=VisibilityObserver.test.js.map